# conver string to byte array
import xmltodict, json

def string_to_bytearray(string):
    if string is None:
        return None                    
    b = bytearray()
    b.extend(map(ord, string))
    return b


def string_to_dict(string):
    return xmltodict.parse(string)


def dict_to_json(dict):
    return json.dumps(dict)


def xml_to_json(xml):
    return dict_to_json(string_to_dict(xml))



from rest_framework import serializers

def dict_get_or_raise_error(dict_, key, message=None):
    value = dict_.get(key, None)
    if value is None:
        if message is None:
            raise serializers.ValidationError({key: "This field is required."})
        else:
            raise serializers.ValidationError({key: message})
    else:
        return value
        


import requests

def get_books_by_query(query, **kwargs):
    headers = kwargs.get("headers", None)
    display = kwargs.get("display", 10)
    start = kwargs.get("start", 1)
    sort = kwargs.get("sort", "count")

    base_url = "https://openapi.naver.com/"
    prefix = "v1/search/book.json?"
    full_url = f"{base_url}{prefix}&query={query}&display={display}&start={start}&sort={sort}"
    return requests.get(full_url, headers=headers)


import jwt

def jwt_decode(*args, **kwargs):
    if args:
        xjwt, encoded_jwt = args[0].split(" ")
        return jwt.decode(encoded_jwt, args[1], algorithms=["HS256"])
    elif kwargs["token"] and kwargs["secret_key"]:
        xjwt, encoded_jwt = kwargs["token"].split(" ")
        return jwt.decode(encoded_jwt, kwargs["secret_key"], algorithms=["HS256"])
    else:
        return False